@@ -1,4 +1,4 @@
-use anyhow::{Context, Result, bail};
+use anyhow::{Context, Result};
 use tokio::fs;
 use yazi_fs::{maybe_exists, ok_or_not_found, remove_dir_clean, remove_sealed};
 use yazi_macro::outln;
@@ -14,36 +14,9 @@ impl Dependency {
 			return Ok(outln!("Not found, skipping")?);
 		}
 
-		if self.hash != self.hash().await? {
-			bail!(
-				"You have modified the contents of the `{}` {}. For safety, the operation has been aborted.
-Please manually delete it from: {}",
-				self.name,
-				if self.is_flavor { "flavor" } else { "plugin" },
-				dir.display()
-			);
-		}
-
-		let files = if self.is_flavor {
-			&["flavor.toml", "tmtheme.xml", "README.md", "preview.png", "LICENSE", "LICENSE-tmtheme"][..]
-		} else {
-			&["main.lua", "README.md", "LICENSE"][..]
-		};
-		for p in files.iter().map(|&f| dir.join(f)) {
-			ok_or_not_found(remove_sealed(&p).await)
-				.with_context(|| format!("failed to delete `{}`", p.display()))?;
-		}
-
+		self.hash_check().await?;
 		self.delete_assets().await?;
-		if ok_or_not_found(fs::remove_dir(&dir).await).is_ok() {
-			outln!("Done!")?;
-		} else {
-			outln!(
-				"Done!
-For safety, user data has been preserved, please manually delete them within: {}",
-				dir.display()
-			)?;
-		}
+		self.delete_sources().await?;
 
 		Ok(())
 	}
@@ -65,4 +38,29 @@ For safety, user data has been preserved, please manually delete them within: {}
 		remove_dir_clean(&assets).await;
 		Ok(())
 	}
+
+	pub(super) async fn delete_sources(&self) -> Result<()> {
+		let dir = self.target();
+		let files = if self.is_flavor {
+			&["flavor.toml", "tmtheme.xml", "README.md", "preview.png", "LICENSE", "LICENSE-tmtheme"][..]
+		} else {
+			&["main.lua", "README.md", "LICENSE"][..]
+		};
+
+		for p in files.iter().map(|&f| dir.join(f)) {
+			ok_or_not_found(remove_sealed(&p).await)
+				.with_context(|| format!("failed to delete `{}`", p.display()))?;
+		}
+
+		if ok_or_not_found(fs::remove_dir(&dir).await).is_ok() {
+			outln!("Done!")?;
+		} else {
+			outln!(
+				"Done!
+For safety, user data has been preserved, please manually delete them within: {}",
+				dir.display()
+			)?;
+		}
+		Ok(())
+	}
 }
