@@ -52,4 +52,17 @@ impl Dependency {
 
 		Ok(format!("{:x}", h.finish_128()))
 	}
+
+	pub(super) async fn hash_check(&self) -> Result<()> {
+		if self.hash != self.hash().await? {
+			bail!(
+				"You have modified the contents of the `{}` {}. For safety, the operation has been aborted.
+Please manually delete it from `{}` and re-run the command.",
+				self.name,
+				if self.is_flavor { "flavor" } else { "plugin" },
+				self.target().display()
+			);
+		}
+		Ok(())
+	}
 }
