@@ -25,67 +25,62 @@ impl Package {
 
 	pub(crate) async fn add_many(&mut self, uses: &[String]) -> Result<()> {
 		for u in uses {
-			if let Err(e) = self.add(u).await {
-				self.save().await?;
-				return Err(e);
-			}
+			let r = self.add(u).await;
+			self.save().await?;
+			r?;
 		}
-		self.save().await
+		Ok(())
 	}
 
 	pub(crate) async fn delete_many(&mut self, uses: &[String]) -> Result<()> {
 		for u in uses {
-			if let Err(e) = self.delete(u).await {
-				self.save().await?;
-				return Err(e);
-			}
+			let r = self.delete(u).await;
+			self.save().await?;
+			r?;
 		}
-		self.save().await
+		Ok(())
 	}
 
 	pub(crate) async fn install(&mut self, upgrade: bool) -> Result<()> {
-		for d in &mut self.plugins {
-			if upgrade {
-				d.upgrade().await?;
-			} else {
-				d.install().await?;
-			}
+		for i in 0..self.plugins.len() {
+			let r =
+				if upgrade { self.plugins[i].upgrade().await } else { self.plugins[i].install().await };
+			self.save().await?;
+			r?;
 		}
-		for d in &mut self.flavors {
-			if upgrade {
-				d.upgrade().await?;
-			} else {
-				d.install().await?;
-			}
+		for i in 0..self.flavors.len() {
+			let r =
+				if upgrade { self.flavors[i].upgrade().await } else { self.flavors[i].install().await };
+			self.save().await?;
+			r?;
 		}
-
-		self.save().await
+		Ok(())
 	}
 
 	pub(crate) fn print(&self) -> Result<()> {
 		outln!("Plugins:")?;
 		for d in &self.plugins {
 			if d.rev.is_empty() {
-				outln!("\t{}", d.use_)?;
+				outln!("\t{}", d.r#use)?;
 			} else {
-				outln!("\t{} ({})", d.use_, d.rev)?;
+				outln!("\t{} ({})", d.r#use, d.rev)?;
 			}
 		}
 
 		outln!("Flavors:")?;
 		for d in &self.flavors {
 			if d.rev.is_empty() {
-				outln!("\t{}", d.use_)?;
+				outln!("\t{}", d.r#use)?;
 			} else {
-				outln!("\t{} ({})", d.use_, d.rev)?;
+				outln!("\t{} ({})", d.r#use, d.rev)?;
 			}
 		}
 
 		Ok(())
 	}
 
-	async fn add(&mut self, use_: &str) -> Result<()> {
-		let mut dep = Dependency::from_str(use_)?;
+	async fn add(&mut self, r#use: &str) -> Result<()> {
+		let mut dep = Dependency::from_str(r#use)?;
 		if let Some(d) = self.identical(&dep) {
 			bail!(
 				"{} `{}` already exists in package.toml",
@@ -103,9 +98,9 @@ impl Package {
 		Ok(())
 	}
 
-	async fn delete(&mut self, use_: &str) -> Result<()> {
-		let Some(dep) = self.identical(&Dependency::from_str(use_)?).cloned() else {
-			bail!("`{}` was not found in package.toml", use_)
+	async fn delete(&mut self, r#use: &str) -> Result<()> {
+		let Some(dep) = self.identical(&Dependency::from_str(r#use)?).cloned() else {
+			bail!("`{}` was not found in package.toml", r#use)
 		};
 
 		dep.delete().await?;
