@@ -1,7 +1,7 @@
 use anyhow::{Result, bail};
 use serde::{Deserialize, Serialize};
 use yazi_codegen::DeserializeOver2;
-use yazi_fs::SortBy;
+use yazi_fs::{CWD, SortBy};
 
 use super::{MgrRatio, MouseEvents};
 
@@ -26,6 +26,21 @@ pub struct Mgr {
 }
 
 impl Mgr {
+	pub fn title(&self) -> Option<String> {
+		if self.title_format.is_empty() {
+			return None;
+		}
+
+		let home = dirs::home_dir().unwrap_or_default();
+		let cwd = if let Ok(p) = CWD.load().strip_prefix(home) {
+			format!("~{}{}", std::path::MAIN_SEPARATOR, p.display())
+		} else {
+			format!("{}", CWD.load().display())
+		};
+
+		Some(self.title_format.replace("{cwd}", &cwd))
+	}
+
 	pub(crate) fn reshape(self) -> Result<Self> {
 		if self.linemode.is_empty() || self.linemode.len() > 20 {
 			bail!("[mgr].linemode must be between 1 and 20 characters.");
