@@ -1,9 +1,10 @@
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::CmdCow;
 
 use crate::help::Help;
 
 impl Help {
-	pub fn escape(&mut self, _: Cmd) {
+	pub fn escape(&mut self, _: CmdCow) {
 		if self.keyword().is_none() {
 			return self.toggle(self.layer);
 		}
