@@ -6,9 +6,9 @@
 	clippy::unit_arg
 )]
 
-yazi_macro::mod_pub!(completion confirm help input manager notify pick spot tab tasks which);
+yazi_macro::mod_pub!(cmp confirm help input mgr notify pick spot tab tasks which);
 
 pub fn init() {
-	manager::WATCHED.with(<_>::default);
-	manager::LINKED.with(<_>::default);
+	mgr::WATCHED.with(<_>::default);
+	mgr::LINKED.with(<_>::default);
 }
