@@ -8,7 +8,8 @@ use yazi_config::YAZI;
 use yazi_dds::Pubsub;
 use yazi_fs::{File, FilesOp, max_common_root, maybe_exists, paths_to_same_file};
 use yazi_proxy::{AppProxy, HIDER, TasksProxy, WATCHER};
-use yazi_shared::{terminal_clear, tty::TTY, url::Url};
+use yazi_shared::{terminal_clear, url::Url};
+use yazi_term::tty::TTY;
 
 use crate::mgr::Mgr;
 
@@ -93,7 +94,7 @@ impl Mgr {
 				failed.push((o, n, anyhow!("Destination already exists")));
 			} else if let Err(e) = fs::rename(&old, &new).await {
 				failed.push((o, n, e.into()));
-			} else if let Ok(f) = File::from(new.into()).await {
+			} else if let Ok(f) = File::new(new.into()).await {
 				succeeded.insert(Url::from(old), f);
 			} else {
 				failed.push((o, n, anyhow!("Failed to retrieve file info")));
@@ -142,7 +143,7 @@ impl Mgr {
 		let mut sorted = Vec::with_capacity(old.len());
 		while !todos.is_empty() {
 			// Paths that are non-incomes and don't need to be prioritized in this round
-			let mut outcomes: Vec<_> = incomes.iter().filter(|(_, &b)| !b).map(|(&p, _)| p).collect();
+			let mut outcomes: Vec<_> = incomes.iter().filter(|&(_, b)| !b).map(|(&p, _)| p).collect();
 			outcomes.sort_unstable_by(|a, b| orders[b].cmp(&orders[a]));
 
 			// If there're no outcomes, it means there are cycles in the renaming
