@@ -19,7 +19,7 @@ impl Mgr {
 		if self.yanked.cut {
 			tasks.file_cut(&src, dest, opt.force);
 
-			self.tabs.iter_mut().for_each(|t| _ = t.selected.remove_many(&src, false));
+			self.tabs.iter_mut().for_each(|t| _ = t.selected.remove_many(&src));
 			self.unyank(());
 		} else {
 			tasks.file_copy(&src, dest, opt.force, opt.follow);
