@@ -1,15 +1,18 @@
+use yazi_fs::Step;
 use yazi_macro::render;
 use yazi_proxy::MgrProxy;
-use yazi_shared::event::{CmdCow, Data};
+use yazi_shared::event::CmdCow;
 
 use crate::spot::Spot;
 
 struct Opt {
-	step: isize,
+	step: Step,
 }
 
 impl From<CmdCow> for Opt {
-	fn from(c: CmdCow) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
+	fn from(c: CmdCow) -> Self {
+		Self { step: c.first().and_then(|d| d.try_into().ok()).unwrap_or_default() }
+	}
 }
 
 impl Spot {
@@ -17,12 +20,12 @@ impl Spot {
 	pub fn arrow(&mut self, opt: Opt) {
 		let Some(lock) = &mut self.lock else { return };
 
+		let new = opt.step.add(self.skip, lock.len().unwrap_or(u16::MAX as _), 0);
 		let Some(old) = lock.selected() else {
-			let new = self.skip.saturating_add_signed(opt.step);
 			return MgrProxy::spot(Some(new));
 		};
 
-		lock.select(Some(old.saturating_add_signed(opt.step)));
+		lock.select(Some(new));
 		let new = lock.selected().unwrap();
 
 		self.skip = new;
