@@ -3,6 +3,7 @@ use std::borrow::Cow;
 use tokio_util::sync::CancellationToken;
 use yazi_config::YAZI;
 use yazi_fs::File;
+use yazi_macro::render;
 use yazi_plugin::{isolate, utils::SpotLock};
 use yazi_shared::url::Url;
 
@@ -36,6 +37,12 @@ impl Spot {
 	#[inline]
 	pub fn abort(&mut self) { self.ct.take().map(|ct| ct.cancel()); }
 
+	#[inline]
+	pub fn reset(&mut self) {
+		self.abort();
+		render!(self.lock.take().is_some());
+	}
+
 	#[inline]
 	pub fn same_url(&self, url: &Url) -> bool { self.lock.as_ref().is_some_and(|l| *url == l.url) }
 
