@@ -28,15 +28,14 @@ impl Tab {
 
 		// Visual selection
 		if let Some((start, items)) = self.mode.visual_mut() {
-			let after = self.current.cursor;
-
-			items.clear();
-			for i in start.min(after)..=after.max(start) {
-				items.insert(i);
-			}
+			let end = self.current.cursor;
+			*items = (start.min(end)..=end.max(start)).collect();
 		}
 
-		MgrProxy::hover(None, self.id);
+		self.hover(None);
+		MgrProxy::peek(false);
+		MgrProxy::watch();
+
 		render!();
 	}
 }
