@@ -109,10 +109,9 @@ impl Tab {
 		let urls: Vec<_> =
 			indices.into_iter().filter_map(|i| self.current.files.get(i)).map(|f| &f.url).collect();
 
-		let same = !self.cwd().is_search();
 		if !select {
-			self.selected.remove_many(&urls, same);
-		} else if self.selected.add_many(&urls, same) != urls.len() {
+			self.selected.remove_many(&urls);
+		} else if self.selected.add_many(&urls) != urls.len() {
 			AppProxy::notify_warn(
 				"Escape visual mode",
 				"Some files cannot be selected, due to path nesting conflict.",
