@@ -27,7 +27,9 @@ impl Tab {
 
 		self.current.repos(hovered.as_ref());
 		if self.hovered().map(|f| f.urn()) != hovered.as_ref().map(|u| u.as_urn()) {
-			MgrProxy::hover(None, self.id);
+			self.hover(None);
+			MgrProxy::peek(false);
+			MgrProxy::watch();
 		}
 
 		render!();
