@@ -25,10 +25,10 @@ impl From<CmdCow> for Opt {
 impl Tab {
 	#[yazi_codegen::command]
 	pub fn find(&mut self, opt: Opt) {
-		tokio::spawn(async move {
-			let rx = InputProxy::show(InputCfg::find(opt.prev));
+		let input = InputProxy::show(InputCfg::find(opt.prev));
 
-			let rx = Debounce::new(UnboundedReceiverStream::new(rx), Duration::from_millis(50));
+		tokio::spawn(async move {
+			let rx = Debounce::new(UnboundedReceiverStream::new(input), Duration::from_millis(50));
 			pin!(rx);
 
 			while let Some(Ok(s)) | Some(Err(InputError::Typed(s))) = rx.next().await {
