@@ -19,6 +19,6 @@ impl Tab {
 			.and_then(|h| h.url.parent_url())
 			.filter(|u| u != self.cwd())
 			.or_else(|| self.cwd().parent_url())
-			.map(|u| self.cd(u.into_regular()));
+			.map(|u| self.cd((u.into_regular(), super::cd::OptSource::Leave)));
 	}
 }
