@@ -11,12 +11,12 @@ impl BodyBye {
 	pub fn owned() -> Body<'static> { Self.into() }
 }
 
-impl<'a> From<BodyBye> for Body<'a> {
+impl From<BodyBye> for Body<'_> {
 	fn from(value: BodyBye) -> Self { Self::Bye(value) }
 }
 
-impl IntoLua<'_> for BodyBye {
-	fn into_lua(self, _: &Lua) -> mlua::Result<Value<'_>> {
+impl IntoLua for BodyBye {
+	fn into_lua(self, _: &Lua) -> mlua::Result<Value> {
 		Err("BodyBye cannot be converted to Lua").into_lua_err()
 	}
 }
