@@ -1,4 +1,3 @@
-use crossterm::terminal::WindowSize;
 use ratatui::layout::Rect;
 use yazi_adapter::Dimension;
 use yazi_shared::event::CmdCow;
@@ -7,7 +6,7 @@ use crate::{app::App, notify};
 
 impl App {
 	pub(crate) fn update_notify(&mut self, cmd: CmdCow) {
-		let WindowSize { rows, columns, .. } = Dimension::available();
+		let Dimension { rows, columns, .. } = Dimension::available();
 		let area =
 			notify::Notify::available(Rect { x: 0, y: 0, width: columns, height: rows });
 
