@@ -2,22 +2,22 @@ use std::ops::Deref;
 
 use mlua::{AnyUserData, MetaMethod, UserData, UserDataMethods};
 
-use super::Lives;
+use super::{Lives, PtrCell};
 
 pub(super) struct Filter {
-	inner: *const yazi_fs::Filter,
+	inner: PtrCell<yazi_fs::Filter>,
 }
 
 impl Deref for Filter {
 	type Target = yazi_fs::Filter;
 
-	fn deref(&self) -> &Self::Target { unsafe { &*self.inner } }
+	fn deref(&self) -> &Self::Target { &self.inner }
 }
 
 impl Filter {
 	#[inline]
 	pub(super) fn make(inner: &yazi_fs::Filter) -> mlua::Result<AnyUserData> {
-		Lives::scoped_userdata(Self { inner })
+		Lives::scoped_userdata(Self { inner: inner.into() })
 	}
 }
 
