@@ -27,13 +27,13 @@ impl Preference {
 
 impl UserData for Preference {
 	fn add_fields<F: UserDataFields<Self>>(fields: &mut F) {
-		cached_field!(fields, sort_by, |_, me: &Self| Ok(me.sort_by.to_string()));
+		cached_field!(fields, sort_by, |_, me| Ok(me.sort_by.to_string()));
 		fields.add_field_method_get("sort_sensitive", |_, me| Ok(me.sort_sensitive));
 		fields.add_field_method_get("sort_reverse", |_, me| Ok(me.sort_reverse));
 		fields.add_field_method_get("sort_dir_first", |_, me| Ok(me.sort_dir_first));
 		fields.add_field_method_get("sort_translit", |_, me| Ok(me.sort_translit));
 
-		cached_field!(fields, linemode, |_, me: &Self| Ok(me.linemode.to_string()));
+		cached_field!(fields, linemode, |_, me| Ok(me.linemode.to_string()));
 		fields.add_field_method_get("show_hidden", |_, me| Ok(me.show_hidden));
 	}
 }
