@@ -1,28 +1,25 @@
 use std::{collections::hash_set, ops::Deref};
 
 use mlua::{AnyUserData, IntoLuaMulti, MetaMethod, UserData, UserDataFields, UserDataMethods, UserDataRefMut};
-use yazi_plugin::url::Url;
+use yazi_binding::Url;
 
-use super::{Iter, Lives};
+use super::{Iter, Lives, PtrCell};
 
 pub(super) struct Yanked {
-	inner: *const yazi_core::mgr::Yanked,
+	inner: PtrCell<yazi_core::mgr::Yanked>,
 }
 
 impl Deref for Yanked {
 	type Target = yazi_core::mgr::Yanked;
 
-	fn deref(&self) -> &Self::Target { self.inner() }
+	fn deref(&self) -> &Self::Target { &self.inner }
 }
 
 impl Yanked {
 	#[inline]
 	pub(super) fn make(inner: &yazi_core::mgr::Yanked) -> mlua::Result<AnyUserData> {
-		Lives::scoped_userdata(Self { inner })
+		Lives::scoped_userdata(Self { inner: inner.into() })
 	}
-
-	#[inline]
-	fn inner(&self) -> &'static yazi_core::mgr::Yanked { unsafe { &*self.inner } }
 }
 
 impl UserData for Yanked {
@@ -37,14 +34,14 @@ impl UserData for Yanked {
 			let iter = lua.create_function(
 				|lua, mut iter: UserDataRefMut<Iter<hash_set::Iter<yazi_shared::url::Url>, _>>| {
 					if let Some(next) = iter.next() {
-						(next.0, Url(next.1.clone())).into_lua_multi(lua)
+						(next.0, Url::new(next.1.clone())).into_lua_multi(lua)
 					} else {
 						().into_lua_multi(lua)
 					}
 				},
 			)?;
 
-			Ok((iter, Iter::make(me.inner().iter())))
+			Ok((iter, Iter::make(me.inner.as_static().iter())))
 		});
 	}
 }
