@@ -1,4 +1,4 @@
-#![allow(clippy::module_inception, clippy::unit_arg)]
+#![allow(clippy::if_same_then_else, clippy::module_inception, clippy::unit_arg)]
 
 #[cfg(all(not(target_os = "macos"), not(target_os = "windows")))]
 #[global_allocator]
@@ -16,6 +16,8 @@ async fn main() -> anyhow::Result<()> {
 	Logs::start()?;
 	_ = fdlimit::raise_fd_limit();
 
+	yazi_term::init();
+
 	yazi_fs::init();
 
 	yazi_config::init()?;
