@@ -79,7 +79,8 @@ end
 function Entity:redraw()
 	local lines = {}
 	for _, c in ipairs(self._children) do
-		lines[#lines + 1] = (type(c[1]) == "string" and self[c[1]] or c[1])(self)
+		local line = (type(c[1]) == "string" and self[c[1]] or c[1])(self)
+		c.width, lines[#lines + 1] = ui.width(line), line
 	end
 	return ui.Line(lines):style(self:style())
 end
@@ -95,6 +96,18 @@ function Entity:style()
 	end
 end
 
+function Entity:ellipsis(max)
+	local adv, f = 0, self._file
+	for _, child in ipairs(self._children) do
+		adv = adv + child.width
+		if adv >= max then
+			return not f.cha.is_dir and f.url.ext and "…." .. f.url.ext or nil
+		elseif child.id == 4 then
+			break
+		end
+	end
+end
+
 -- Children
 function Entity:children_add(fn, order)
 	self._inc = self._inc + 1
