@@ -1,4 +1,5 @@
 Status = {
+	-- TODO: remove these two constants
 	LEFT = 0,
 	RIGHT = 1,
 
@@ -140,9 +141,9 @@ function Status:redraw()
 
 	return {
 		ui.Text(""):area(self._area):style(th.status.overall),
-		ui.Text(left):area(self._area),
-		ui.Text(right):area(self._area):align(ui.Text.RIGHT),
-		table.unpack(ya.redraw_with(Progress:new(self._area, right_width))),
+		ui.Line(left):area(self._area),
+		ui.Line(right):area(self._area):align(ui.Align.RIGHT),
+		table.unpack(ui.redraw(Progress:new(self._area, right_width))),
 	}
 end
 
