@@ -1,10 +1,6 @@
 local M = {}
 
-function M.msg(job, s)
-	ya.preview_widgets(job, {
-		ui.Text(ui.Line(s):reverse()):area(job.area):wrap(ui.Text.WRAP),
-	})
-end
+function M.msg(job, s) ya.preview_widget(job, ui.Text(ui.Line(s):reverse()):area(job.area):wrap(ui.Wrap.YES)) end
 
 function M:peek(job)
 	local path = tostring(job.file.url)
@@ -41,9 +37,9 @@ function M:peek(job)
 	end
 
 	if job.skip > 0 and i < job.skip + limit then
-		ya.mgr_emit("peek", { math.max(0, i - limit), only_if = job.file.url, upper_bound = true })
+		ya.emit("peek", { math.max(0, i - limit), only_if = job.file.url, upper_bound = true })
 	else
-		ya.preview_widgets(job, { ui.Text(lines):area(job.area) })
+		ya.preview_widget(job, ui.Text(lines):area(job.area))
 	end
 end
 
