@@ -14,8 +14,9 @@ function M:peek(job)
 	end
 
 	ya.sleep(math.max(0, rt.preview.image_delay / 1000 + start - os.clock()))
-	ya.image_show(cache, job.area)
-	ya.preview_widgets(job, {})
+
+	local _, err = ya.image_show(cache, job.area)
+	ya.preview_widget(job, err and ui.Text(tostring(err)):area(job.area):wrap(ui.Wrap.YES))
 end
 
 function M:seek() end
@@ -26,7 +27,7 @@ function M:preload(job)
 		return true
 	end
 
-	local status, err = Command("magick"):args({
+	local status, err = Command("magick"):arg({
 		"-size",
 		"800x560",
 		"-gravity",
