@@ -12,8 +12,9 @@ function M:peek(job)
 	end
 
 	ya.sleep(math.max(0, rt.preview.image_delay / 1000 + start - os.clock()))
-	ya.image_show(cache, job.area)
-	ya.preview_widgets(job, {})
+
+	local _, err = ya.image_show(cache, job.area)
+	ya.preview_widget(job, err and ui.Text(tostring(err)):area(job.area):wrap(ui.Wrap.YES))
 end
 
 function M:seek() end
@@ -24,13 +25,13 @@ function M:preload(job)
 		return true
 	end
 
-	local cmd = M.with_env()
+	local cmd = M.with_limit()
 	if job.args.flatten then
 		cmd = cmd:arg("-flatten")
 	end
 
 	-- stylua: ignore
-	local status, err = cmd:args {
+	local status, err = cmd:arg {
 		tostring(job.file.url), "-auto-orient", "-strip",
 		"-sample", string.format("%dx%d>", rt.preview.max_width, rt.preview.max_height),
 		"-quality", rt.preview.image_quality,
@@ -46,10 +47,16 @@ end
 
 function M:spot(job) require("file"):spot(job) end
 
-function M.with_env()
-	local cmd = Command("magick"):env("MAGICK_THREAD_LIMIT", 1)
+function M.with_limit()
+	local cmd = Command("magick"):arg { "-limit", "thread", 1 }
 	if rt.tasks.image_alloc > 0 then
-		cmd = cmd:env("MAGICK_MEMORY_LIMIT", rt.tasks.image_alloc)
+		cmd:arg { "-limit", "memory", rt.tasks.image_alloc, "-limit", "disk", "1MiB" }
+	end
+	if rt.tasks.image_bound[1] > 0 then
+		cmd:arg { "-limit", "width", rt.tasks.image_bound[1] }
+	end
+	if rt.tasks.image_bound[2] > 0 then
+		cmd:arg { "-limit", "height", rt.tasks.image_bound[2] }
 	end
 	return cmd
 end
