@@ -4,9 +4,9 @@ function M:peek() end
 
 function M:seek() end
 
-function M:fetch() return 1 end
+function M:fetch() return true end
 
-function M:preload() return 1 end
+function M:preload() return true end
 
 function M:spot() end
 
