@@ -12,8 +12,9 @@ function M:peek(job)
 	end
 
 	ya.sleep(math.max(0, rt.preview.image_delay / 1000 + start - os.clock()))
-	ya.image_show(cache, job.area)
-	ya.preview_widgets(job, {})
+
+	local _, err = ya.image_show(cache, job.area)
+	ya.preview_widget(job, err and ui.Text(tostring(err)):area(job.area):wrap(ui.Wrap.YES))
 end
 
 function M:seek() end
@@ -25,7 +26,7 @@ function M:preload(job)
 	end
 
 	-- stylua: ignore
-	local cmd = Command("resvg"):args {
+	local cmd = Command("resvg"):arg {
 		"-w", rt.preview.max_width, "-h", rt.preview.max_height,
 		"--image-rendering", "optimizeSpeed",
 		tostring(job.file.url), tostring(cache)
