@@ -4,7 +4,7 @@ use mlua::{ExternalError, FromLua, IntoLua, Lua, Table, UserData, UserDataFields
 use yazi_fs::cha::ChaKind;
 
 #[derive(Clone, Copy, FromLua)]
-pub struct Cha(yazi_fs::cha::Cha);
+pub struct Cha(pub yazi_fs::cha::Cha);
 
 impl Deref for Cha {
 	type Target = yazi_fs::cha::Cha;
@@ -12,10 +12,6 @@ impl Deref for Cha {
 	fn deref(&self) -> &Self::Target { &self.0 }
 }
 
-impl<T: Into<yazi_fs::cha::Cha>> From<T> for Cha {
-	fn from(cha: T) -> Self { Self(cha.into()) }
-}
-
 impl Cha {
 	pub fn install(lua: &Lua) -> mlua::Result<()> {
 		#[inline]
@@ -33,7 +29,7 @@ impl Cha {
 				let kind =
 					ChaKind::from_bits(t.raw_get("kind")?).ok_or_else(|| "Invalid kind".into_lua_err())?;
 
-				Self::from(yazi_fs::cha::Cha {
+				Self(yazi_fs::cha::Cha {
 					kind,
 					len: t.raw_get("len").unwrap_or_default(),
 					atime: parse_time(t.raw_get("atime").ok())?,
