@@ -1,6 +1,6 @@
 use std::sync::atomic::{AtomicBool, Ordering};
 
-use mlua::{Lua, MetaMethod, Table, UserData};
+use mlua::{IntoLua, Lua, MetaMethod, Table, UserData, Value};
 use yazi_adapter::ADAPTOR;
 
 use super::Area;
@@ -13,13 +13,13 @@ pub struct Clear {
 }
 
 impl Clear {
-	pub fn compose(lua: &Lua) -> mlua::Result<Table> {
+	pub fn compose(lua: &Lua) -> mlua::Result<Value> {
 		let new = lua.create_function(|_, (_, area): (Table, Area)| Ok(Clear { area }))?;
 
 		let clear = lua.create_table()?;
 		clear.set_metatable(Some(lua.create_table_from([(MetaMethod::Call.name(), new)])?));
 
-		Ok(clear)
+		clear.into_lua(lua)
 	}
 
 	pub(super) fn render(
