@@ -4,7 +4,7 @@ use tokio::fs;
 use yazi_binding::{Error, Url, UrlRef};
 use yazi_fs::{mounts::PARTITIONS, remove_dir_clean};
 
-use crate::{Composer, bindings::Cha, file::File};
+use crate::{Composer, bindings::{Cha, SizeCalculator}, file::File};
 
 pub fn compose(lua: &Lua) -> mlua::Result<Value> {
 	Composer::make(lua, 10, |lua, key| {
@@ -16,6 +16,7 @@ pub fn compose(lua: &Lua) -> mlua::Result<Value> {
 			b"create" => create(lua)?,
 			b"remove" => remove(lua)?,
 			b"read_dir" => read_dir(lua)?,
+			b"calc_size" => calc_size(lua)?,
 			b"expand_url" => expand_url(lua)?,
 			b"unique_name" => unique_name(lua)?,
 			b"partitions" => partitions(lua)?,
@@ -29,13 +30,14 @@ fn op(lua: &Lua) -> mlua::Result<Function> {
 	lua.create_function(|lua, (name, t): (mlua::String, Table)| match name.as_bytes().as_ref() {
 		b"part" => super::FilesOp::part(lua, t),
 		b"done" => super::FilesOp::done(lua, t),
+		b"size" => super::FilesOp::size(lua, t),
 		_ => Err("Unknown operation".into_lua_err())?,
 	})
 }
 
 fn cwd(lua: &Lua) -> mlua::Result<Function> {
 	lua.create_function(|lua, ()| match std::env::current_dir() {
-		Ok(p) => (Url::new(p), Value::Nil).into_lua_multi(lua),
+		Ok(p) => Url::new(p).into_lua_multi(lua),
 		Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(lua),
 	})
 }
@@ -49,7 +51,7 @@ fn cha(lua: &Lua) -> mlua::Result<Function> {
 		};
 
 		match meta {
-			Ok(m) => (Cha::from(m), Value::Nil).into_lua_multi(&lua),
+			Ok(m) => Cha(yazi_fs::cha::Cha::new(&url, m)).into_lua_multi(&lua),
 			Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
 		}
 	})
@@ -58,30 +60,30 @@ fn cha(lua: &Lua) -> mlua::Result<Function> {
 fn write(lua: &Lua) -> mlua::Result<Function> {
 	lua.create_async_function(|lua, (url, data): (UrlRef, mlua::String)| async move {
 		match fs::write(&*url, data.as_bytes()).await {
-			Ok(()) => (true, Value::Nil).into_lua_multi(&lua),
+			Ok(()) => true.into_lua_multi(&lua),
 			Err(e) => (false, Error::Io(e)).into_lua_multi(&lua),
 		}
 	})
 }
 
 fn create(lua: &Lua) -> mlua::Result<Function> {
-	lua.create_async_function(|lua, (type_, url): (mlua::String, UrlRef)| async move {
-		let result = match type_.as_bytes().as_ref() {
+	lua.create_async_function(|lua, (r#type, url): (mlua::String, UrlRef)| async move {
+		let result = match r#type.as_bytes().as_ref() {
 			b"dir" => fs::create_dir(&*url).await,
 			b"dir_all" => fs::create_dir_all(&*url).await,
 			_ => Err("Creation type must be 'dir' or 'dir_all'".into_lua_err())?,
 		};
 
 		match result {
-			Ok(()) => (true, Value::Nil).into_lua_multi(&lua),
+			Ok(()) => true.into_lua_multi(&lua),
 			Err(e) => (false, Error::Io(e)).into_lua_multi(&lua),
 		}
 	})
 }
 
 fn remove(lua: &Lua) -> mlua::Result<Function> {
-	lua.create_async_function(|lua, (type_, url): (mlua::String, UrlRef)| async move {
-		let result = match type_.as_bytes().as_ref() {
+	lua.create_async_function(|lua, (r#type, url): (mlua::String, UrlRef)| async move {
+		let result = match r#type.as_bytes().as_ref() {
 			b"file" => fs::remove_file(&*url).await,
 			b"dir" => fs::remove_dir(&*url).await,
 			b"dir_all" => fs::remove_dir_all(&*url).await,
@@ -90,7 +92,7 @@ fn remove(lua: &Lua) -> mlua::Result<Function> {
 		};
 
 		match result {
-			Ok(()) => (true, Value::Nil).into_lua_multi(&lua),
+			Ok(()) => true.into_lua_multi(&lua),
 			Err(e) => (false, Error::Io(e)).into_lua_multi(&lua),
 		}
 	})
@@ -136,7 +138,7 @@ fn read_dir(lua: &Lua) -> mlua::Result<Function> {
 			let file = if !resolve {
 				yazi_fs::File::from_dummy(url, next.file_type().await.ok())
 			} else if let Ok(meta) = next.metadata().await {
-				yazi_fs::File::from_meta(url, meta).await
+				yazi_fs::File::from_follow(url, meta).await
 			} else {
 				yazi_fs::File::from_dummy(url, next.file_type().await.ok())
 			};
@@ -148,7 +150,16 @@ fn read_dir(lua: &Lua) -> mlua::Result<Function> {
 			tbl.raw_push(f)?;
 		}
 
-		(tbl, Value::Nil).into_lua_multi(&lua)
+		tbl.into_lua_multi(&lua)
+	})
+}
+
+fn calc_size(lua: &Lua) -> mlua::Result<Function> {
+	lua.create_async_function(|lua, url: UrlRef| async move {
+		match yazi_fs::SizeCalculator::new(&*url).await {
+			Ok(it) => SizeCalculator(it).into_lua_multi(&lua),
+			Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
+		}
 	})
 }
 
@@ -166,7 +177,7 @@ fn expand_url(lua: &Lua) -> mlua::Result<Function> {
 fn unique_name(lua: &Lua) -> mlua::Result<Function> {
 	lua.create_async_function(|lua, url: UrlRef| async move {
 		match yazi_fs::unique_name(url.clone(), async { false }).await {
-			Ok(u) => (Url::new(u), Value::Nil).into_lua_multi(&lua),
+			Ok(u) => Url::new(u).into_lua_multi(&lua),
 			Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
 		}
 	})
