@@ -1,3 +1,3 @@
 #![allow(clippy::module_inception)]
 
-yazi_macro::mod_flat!(fs);
+yazi_macro::mod_flat!(fs op);
