@@ -1,7 +1,7 @@
 use mlua::{IntoLua, Lua, Table};
-use yazi_binding::Url;
+use yazi_binding::{Id, Url, Urn};
 
-use crate::{Id, bindings::Cha, file::File};
+use crate::{bindings::Cha, file::File};
 
 pub(super) struct FilesOp(yazi_fs::FilesOp);
 
@@ -28,6 +28,19 @@ impl FilesOp {
 
 		Ok(Self(yazi_fs::FilesOp::Done(url.into(), *cha, *id)))
 	}
+
+	pub(super) fn size(_: &Lua, t: Table) -> mlua::Result<Self> {
+		let url: Url = t.raw_get("url")?;
+		let sizes: Table = t.raw_get("sizes")?;
+
+		Ok(Self(yazi_fs::FilesOp::Size(
+			url.into(),
+			sizes
+				.pairs::<Urn, u64>()
+				.map(|r| r.map(|(urn, size)| (urn.into(), size)))
+				.collect::<mlua::Result<_>>()?,
+		)))
+	}
 }
 
 impl IntoLua for FilesOp {
