@@ -6,7 +6,6 @@ use crate::runtime::Runtime;
 pub fn slim_lua(name: &str) -> mlua::Result<Lua> {
 	let lua = Lua::new();
 	lua.set_named_registry_value("ir", Runtime::new(name))?;
-	crate::config::Runtime::new(&lua).install_preview()?;
 
 	// Base
 	let globals = lua.globals();
@@ -17,10 +16,10 @@ pub fn slim_lua(name: &str) -> mlua::Result<Lua> {
 	globals.raw_set("th", crate::config::Theme::compose(&lua)?)?;
 
 	crate::bindings::Cha::install(&lua)?;
-	crate::file::pour(&lua)?;
-	crate::url::pour(&lua)?;
+	crate::file::File::install(&lua)?;
+	yazi_binding::Url::install(&lua)?;
 
-	crate::Error::install(&lua)?;
+	yazi_binding::Error::install(&lua)?;
 	crate::loader::install_isolate(&lua)?;
 	crate::process::install(&lua)?;
 
