@@ -11,16 +11,18 @@ macro_rules! impl_style_method {
 #[macro_export]
 macro_rules! impl_area_method {
 	($methods:ident) => {
-		use mlua::{AnyUserData, IntoLua};
-
-		$methods.add_function_mut("area", |lua, (ud, area): (AnyUserData, Option<AnyUserData>)| {
-			if let Some(v) = area {
-				ud.borrow_mut::<Self>()?.area = $crate::elements::Area::try_from(v)?;
-				ud.into_lua(lua)
-			} else {
-				ud.borrow::<Self>()?.area.into_lua(lua)
-			}
-		});
+		$methods.add_function_mut(
+			"area",
+			|lua, (ud, area): (mlua::AnyUserData, Option<mlua::AnyUserData>)| {
+				use mlua::IntoLua;
+				if let Some(v) = area {
+					ud.borrow_mut::<Self>()?.area = $crate::elements::Area::try_from(v)?;
+					ud.into_lua(lua)
+				} else {
+					ud.borrow::<Self>()?.area.into_lua(lua)
+				}
+			},
+		);
 	};
 }
 
@@ -81,17 +83,13 @@ macro_rules! impl_style_shorthands {
 #[macro_export]
 macro_rules! impl_file_fields {
 	($fields:ident) => {
-		yazi_binding::cached_field!($fields, cha, |_, me: &Self| Ok($crate::bindings::Cha::from(
-			me.cha
-		)));
-		yazi_binding::cached_field!($fields, url, |_, me: &Self| Ok(yazi_binding::Url::new(
-			me.url_owned()
-		)));
-		yazi_binding::cached_field!($fields, link_to, |_, me: &Self| Ok(
+		yazi_binding::cached_field!($fields, cha, |_, me| Ok($crate::bindings::Cha(me.cha)));
+		yazi_binding::cached_field!($fields, url, |_, me| Ok(yazi_binding::Url::new(me.url_owned())));
+		yazi_binding::cached_field!($fields, link_to, |_, me| Ok(
 			me.link_to.clone().map(yazi_binding::Url::new)
 		));
 
-		yazi_binding::cached_field!($fields, name, |lua: &mlua::Lua, me: &Self| {
+		yazi_binding::cached_field!($fields, name, |lua, me| {
 			Some(me.name())
 				.filter(|s| !s.is_empty())
 				.map(|s| lua.create_string(s.as_encoded_bytes()))
