@@ -135,11 +135,30 @@ impl UserData for Command {
 			)
 		}
 
-		methods.add_function_mut("arg", |_, (ud, arg): (AnyUserData, mlua::String)| {
-			ud.borrow_mut::<Self>()?.inner.arg(arg.to_string_lossy());
+		methods.add_function_mut("arg", |_, (ud, arg): (AnyUserData, Value)| {
+			{
+				let mut me = ud.borrow_mut::<Self>()?;
+				match arg {
+					Value::String(s) => {
+						me.inner.arg(String::from_utf8_lossy(&s.as_bytes()).as_ref());
+					}
+					Value::Table(t) => {
+						for s in t.sequence_values::<mlua::String>() {
+							me.inner.arg(String::from_utf8_lossy(&s?.as_bytes()).as_ref());
+						}
+					}
+					_ => return Err("arg must be a string or table of strings".into_lua_err()),
+				}
+			}
 			Ok(ud)
 		});
-		methods.add_function_mut("args", |_, (ud, args): (AnyUserData, Vec<mlua::String>)| {
+		// TODO: remove this
+		methods.add_function_mut("args", |lua, (ud, args): (AnyUserData, Vec<mlua::String>)| {
+			crate::deprecate!(
+				lua,
+				"The `args()` method on `Command` is deprecated, use `arg()` instead in your {}\n\nSee #2752 for more details: https://github.com/sxyazi/yazi/pull/2752"
+			);
+
 			{
 				let mut me = ud.borrow_mut::<Self>()?;
 				for arg in args {
@@ -155,7 +174,10 @@ impl UserData for Command {
 		methods.add_function_mut(
 			"env",
 			|_, (ud, key, value): (AnyUserData, mlua::String, mlua::String)| {
-				ud.borrow_mut::<Self>()?.inner.env(key.to_string_lossy(), value.to_string_lossy());
+				ud.borrow_mut::<Self>()?.inner.env(
+					String::from_utf8_lossy(&key.as_bytes()).as_ref(),
+					String::from_utf8_lossy(&value.as_bytes()).as_ref(),
+				);
 				Ok(ud)
 			},
 		);
@@ -176,18 +198,18 @@ impl UserData for Command {
 			Ok(ud)
 		});
 		methods.add_method_mut("spawn", |lua, me, ()| match me.spawn() {
-			Ok(child) => (child, Value::Nil).into_lua_multi(lua),
+			Ok(child) => child.into_lua_multi(lua),
 			Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(lua),
 		});
 		methods.add_async_method_mut("output", |lua, mut me, ()| async move {
 			match me.output().await {
-				Ok(output) => (Output::new(output), Value::Nil).into_lua_multi(&lua),
+				Ok(output) => Output::new(output).into_lua_multi(&lua),
 				Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
 			}
 		});
 		methods.add_async_method_mut("status", |lua, mut me, ()| async move {
 			match me.status().await {
-				Ok(status) => (Status::new(status), Value::Nil).into_lua_multi(&lua),
+				Ok(status) => Status::new(status).into_lua_multi(&lua),
 				Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
 			}
 		});
