@@ -1,6 +1,6 @@
-use mlua::{Function, IntoLua, Lua, Value};
+use mlua::{Function, IntoLuaMulti, Lua, Value};
 use yazi_adapter::{ADAPTOR, Image};
-use yazi_binding::UrlRef;
+use yazi_binding::{Error, UrlRef};
 
 use super::Utils;
 use crate::{bindings::ImageInfo, elements::Rect};
@@ -8,20 +8,18 @@ use crate::{bindings::ImageInfo, elements::Rect};
 impl Utils {
 	pub(super) fn image_info(lua: &Lua) -> mlua::Result<Function> {
 		lua.create_async_function(|lua, url: UrlRef| async move {
-			if let Ok(info) = yazi_adapter::ImageInfo::new(&url).await {
-				ImageInfo::from(info).into_lua(&lua)
-			} else {
-				Value::Nil.into_lua(&lua)
+			match yazi_adapter::ImageInfo::new(&url).await {
+				Ok(info) => ImageInfo::from(info).into_lua_multi(&lua),
+				Err(e) => (Value::Nil, Error::Custom(e.to_string())).into_lua_multi(&lua),
 			}
 		})
 	}
 
 	pub(super) fn image_show(lua: &Lua) -> mlua::Result<Function> {
 		lua.create_async_function(|lua, (url, rect): (UrlRef, Rect)| async move {
-			if let Ok(area) = ADAPTOR.get().image_show(&url, *rect).await {
-				Rect::from(area).into_lua(&lua)
-			} else {
-				Value::Nil.into_lua(&lua)
+			match ADAPTOR.get().image_show(&url, *rect).await {
+				Ok(area) => Rect::from(area).into_lua_multi(&lua),
+				Err(e) => (Value::Nil, Error::Custom(e.to_string())).into_lua_multi(&lua),
 			}
 		})
 	}
