@@ -20,10 +20,10 @@ impl Utils {
 			for (i, cand) in t.raw_get::<Table>("cands")?.sequence_values::<Table>().enumerate() {
 				let cand = cand?;
 				cands.push(Chord {
-					on:   Self::parse_keys(cand.raw_get("on")?)?,
-					run:  vec![Cmd::args("which:callback", &[i]).with_any("tx", tx.clone())],
-					desc: cand.raw_get("desc").ok(),
-					for_: None,
+					on:    Self::parse_keys(cand.raw_get("on")?)?,
+					run:   vec![Cmd::args("which:callback", &[i]).with_any("tx", tx.clone())],
+					desc:  cand.raw_get("desc").ok(),
+					r#for: None,
 				});
 			}
 
@@ -45,10 +45,10 @@ impl Utils {
 				title: t.raw_get("title")?,
 				value: t.raw_get("value").unwrap_or_default(),
 				cursor: None, // TODO
+				obscure: t.raw_get("obscure").unwrap_or_default(),
 				position: Pos::new_input(t.raw_get::<Table>("position")?)?.into(),
 				realtime,
 				completion: false,
-				highlight: false,
 			}));
 
 			if !realtime {
@@ -59,20 +59,18 @@ impl Utils {
 			if debounce < 0.0 {
 				Err("negative debounce duration".into_lua_err())
 			} else if debounce == 0.0 {
-				(InputRx::new(rx), Value::Nil).into_lua_multi(&lua)
+				InputRx::new(rx).into_lua_multi(&lua)
 			} else {
-				(InputRx::new(Debounce::new(rx, Duration::from_secs_f64(debounce))), Value::Nil)
-					.into_lua_multi(&lua)
+				InputRx::new(Debounce::new(rx, Duration::from_secs_f64(debounce))).into_lua_multi(&lua)
 			}
 		})
 	}
 
 	pub(super) fn confirm(lua: &Lua) -> mlua::Result<Function> {
 		fn content(t: &Table) -> mlua::Result<ratatui::widgets::Paragraph<'static>> {
-			Ok(match t.raw_get::<Value>("content") {
-				Ok(v) if v.is_nil() => Default::default(),
-				Ok(v) => Text::try_from(v)?.into(),
-				Err(e) => Err(e)?,
+			Ok(match t.raw_get::<Value>("content")? {
+				Value::Nil => Default::default(),
+				v => Text::try_from(v)?.into(),
 			})
 		}
 
