@@ -1,16 +1,17 @@
 use mlua::{AnyUserData, Function, Lua, Table};
 use yazi_config::THEME;
 use yazi_macro::emit;
-use yazi_shared::event::Cmd;
+use yazi_shared::{Id, event::Cmd};
 
 use super::Utils;
-use crate::{elements::Renderable, file::FileRef};
+use crate::{elements::{Edge, Renderable}, file::FileRef};
 
 pub struct SpotLock {
 	pub url:  yazi_shared::url::Url,
 	pub cha:  yazi_fs::cha::Cha,
 	pub mime: String,
 
+	pub id:   Id,
 	pub skip: usize,
 	pub data: Vec<Renderable>,
 }
@@ -25,6 +26,7 @@ impl TryFrom<Table> for SpotLock {
 			cha:  file.cha,
 			mime: t.raw_get("mime")?,
 
+			id:   *t.raw_get::<yazi_binding::Id>("id")?,
 			skip: t.raw_get("skip")?,
 			data: Default::default(),
 		})
@@ -71,8 +73,8 @@ impl Utils {
 				Renderable::Clear(crate::elements::Clear { area }),
 				Renderable::Border(crate::elements::Border {
 					area,
-					position: ratatui::widgets::Borders::ALL,
-					type_: ratatui::widgets::BorderType::Rounded,
+					edge: Edge(ratatui::widgets::Borders::ALL),
+					r#type: ratatui::widgets::BorderType::Rounded,
 					style: THEME.spot.border.into(),
 					titles: vec![(
 						ratatui::widgets::block::Position::Top,
