@@ -16,7 +16,7 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 
 			// Call
 			b"render" => Utils::render(lua)?,
-			b"redraw_with" => Utils::redraw_with(lua)?,
+			b"emit" => Utils::emit(lua)?,
 			b"app_emit" => Utils::app_emit(lua)?,
 			b"mgr_emit" => Utils::mgr_emit(lua)?,
 			b"manager_emit" => Utils::mgr_emit(lua)?, // TODO: remove this in the future
@@ -43,7 +43,8 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 
 			// Preview
 			b"preview_code" => Utils::preview_code(lua)?,
-			b"preview_widgets" => Utils::preview_widgets(lua)?,
+			b"preview_widget" => Utils::preview_widget(lua)?,
+			b"preview_widgets" => Utils::preview_widget(lua)?, // TODO: remove this in the future
 
 			// Process
 			b"proc_info" => Utils::proc_info(lua)?,
@@ -63,7 +64,7 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 			b"target_family" => Utils::target_family(lua)?,
 
 			// Text
-			b"hash" => Utils::hash(lua, false)?,
+			b"hash" => Utils::hash(lua)?,
 			b"quote" => Utils::quote(lua)?,
 			b"truncate" => Utils::truncate(lua)?,
 			b"clipboard" => Utils::clipboard(lua)?,
