@@ -1,7 +1,7 @@
 use tokio::sync::oneshot;
 use yazi_config::popup::ConfirmCfg;
 use yazi_macro::emit;
-use yazi_shared::{Layer, event::Cmd};
+use yazi_shared::event::Cmd;
 
 pub struct ConfirmProxy;
 
@@ -12,7 +12,7 @@ impl ConfirmProxy {
 	#[inline]
 	pub fn show_rx(cfg: ConfirmCfg) -> oneshot::Receiver<bool> {
 		let (tx, rx) = oneshot::channel();
-		emit!(Call(Cmd::new("show").with_any("tx", tx).with_any("cfg", cfg), Layer::Confirm));
+		emit!(Call(Cmd::new("confirm:show").with_any("tx", tx).with_any("cfg", cfg)));
 		rx
 	}
 }
