@@ -1,4 +1,4 @@
-use std::{borrow::Cow, fmt::Display};
+use std::borrow::Cow;
 
 use yazi_shared::event::CmdCow;
 
@@ -24,7 +24,9 @@ impl TryFrom<CmdCow> for SearchOpt {
 			via,
 			subject,
 			// TODO: use second positional argument instead of `args` parameter
-			args: yazi_shared::shell::split_unix(c.str("args").unwrap_or_default()).map_err(|_| ())?,
+			args: yazi_shared::shell::split_unix(c.str("args").unwrap_or_default(), false)
+				.map_err(|_| ())?
+				.0,
 			args_raw: c.take_str("args").unwrap_or_default(),
 		})
 	}
@@ -33,31 +35,27 @@ impl TryFrom<CmdCow> for SearchOpt {
 // Via
 #[derive(PartialEq, Eq)]
 pub enum SearchOptVia {
-	// TODO: remove `None` in the future
-	None,
 	Rg,
-	Fd,
 	Rga,
+	Fd,
 }
 
 impl From<&str> for SearchOptVia {
 	fn from(value: &str) -> Self {
 		match value {
 			"rg" => Self::Rg,
-			"fd" => Self::Fd,
 			"rga" => Self::Rga,
-			_ => Self::None,
+			_ => Self::Fd,
 		}
 	}
 }
 
-impl Display for SearchOptVia {
-	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-		f.write_str(match self {
+impl AsRef<str> for SearchOptVia {
+	fn as_ref(&self) -> &str {
+		match self {
 			Self::Rg => "rg",
-			Self::Fd => "fd",
 			Self::Rga => "rga",
-			Self::None => "none",
-		})
+			Self::Fd => "fd",
+		}
 	}
 }
