@@ -1,4 +1,4 @@
-use std::{cell::Cell, fmt::{Debug, Formatter}, ops::Deref};
+use std::{cell::Cell, fmt::{Debug, Display, Formatter}, ops::Deref};
 
 /// [`SyncCell`], but [`Sync`].
 ///
@@ -30,7 +30,9 @@ impl<T: Copy> Clone for SyncCell<T> {
 }
 
 impl<T: Copy + Debug> Debug for SyncCell<T> {
-	fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-		f.debug_struct("SyncCell").field("value", &self.get()).finish()
-	}
+	fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result { Debug::fmt(&self.get(), f) }
+}
+
+impl<T: Copy + Display> Display for SyncCell<T> {
+	fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result { Display::fmt(&self.get(), f) }
 }
